( cd sbin ; rm -rf ksyms )
( cd sbin ; ln -sf insmod ksyms )
( cd sbin ; rm -rf lsmod )
( cd sbin ; ln -sf insmod lsmod )
( cd sbin ; rm -rf modprobe )
( cd sbin ; ln -sf insmod modprobe )
( cd sbin ; rm -rf rmmod )
( cd sbin ; ln -sf insmod rmmod )
( cd sbin ; rm -rf kallsyms )
( cd sbin ; ln -sf insmod kallsyms )
# Dont install modules.conf-sample as etc/modules.conf, if one already exists
if [ ! -f etc/modules.conf ]; then
  mv etc/modules.conf-sample etc/modules.conf
fi

